Stan Math Library: stan/math/rev/scal/meta/is_var.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_var.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_META_IS_VAR_HPP
2 #define STAN_MATH_REV_SCAL_META_IS_VAR_HPP
3
4 #include <stan/math/prim/scal/meta/is_var.hpp>
5 #include <stan/math/rev/core.hpp>
6
7 namespace stan {
8
9 template <>
10 struct is_var<stan::math::var> {
11 enum { value = true };
12 };
13
14 }
15 #endif
16
core.hpp
stan::is_var::value
Definition: is_var.hpp:8
stan
Definition: log_sum_exp.hpp:8
stan::is_var
Definition: is_var.hpp:7
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
is_var.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.